Kamenický encoding - Wikipedia

# Kamenický encoding

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

Kamenický encoding
Alias(es) | NEC-867,[A] DOS-895,[B] KEYBCS2
Language(s) | Czech, Slovak
Classification | Extended ASCII, OEM code page
Based on | OEM-US
^ Not IBM-867, which is a Hebrew encoding. ^ Not IBM-895, which is used on AIX for the Roman set of JIS X 0201.

The Kamenický encoding (Czech: kódování Kamenických), named for the brothers Jiří and Marian Kamenický,[1] was a code page for personal computers running DOS, very popular in Czechoslovakia (since 1993, the Czech Republic and Slovakia) around 1985–1995. Another name for this encoding is `KEYBCS2`,[1] the name of the Terminate and Stay Resident utility which implemented the matching keyboard driver. It was also named `KAMENICKY`.[1]

It was based on the code page 437 encoding (with accented characters for Western-European languages) where most of the characters from code points 128 to 173 were replaced by Czech and Slovak characters chosen so that the glyphs of the replacement characters resembled those of the original as closely as possible, e. g. č in the place of ç. This ensured that text in the Kamenický encoding was (barely) readable even on older or cheap computers with the original fonts (which were often in videocard ROM, making modification difficult if not impossible).

A supplemental feature was that the block graphic and box-drawing characters of code page 437 remained unchanged (IBM's official Central-European code page 852 did not have this property, making programs like Norton Commander look funny with corners and joints of border lines broken by accented letters). The widespread use of the Kamenický encoding was undermined neither by IBM's code page 852, nor by the Windows 3.1 introducing Microsoft Central Europe code page 1250. Only with Windows 95 and the spreading deployment of Microsoft Office did users begin to use code page 1250, which in turn is now obsoleted by Unicode.

Some ambiguity exists in the official code page assignment for the Kamenický encoding:

Some dot matrix printers of the NEC Pinwriter series, namely the P3200/P3300 (P20/P30), P6200/P6300 (P60/P70), P9300 (P90), P7200/P7300 (P62/P72), P22Q/P32Q, P3800/P3900 (P42Q/P52Q), P1200/P1300 (P2Q/P3Q), P2000 (P2X) and P8000 (P72X), supported the installation of optional font EPROMs.[2] The optional ROM #2 "East Europe" included this encoding, invokable via escape sequence `ESC R (n)` with (n) = 23. While named "Kamenický" in the documentation,[2] it was originally advertised by NEC as code page 867 (CP867) or "Czech".[3] (However, it was never registered with IBM under that ID, as IBM registered another unrelated code page Israel: Hebrew, based on CP862, under that ID in 1998.[4]) The Fujitsu DL6400 (Pro) / DL6600 (Pro) printers support the Kamenický encoding as well.[5]

The encoding was also sometimes called code page 895 (CP895),[6] for example with FoxPro,[1] in the WordPerfect[7][8] text processor and under the Arachne[8] web browser for DOS, but IBM uses this code page number for a different encoding,[1] CM/Group 2: 7-bit Latin SBCS: Japanese (EUC-JP JIS-Roman)[8][9] or Japan 7-Bit Latin (00895),[10] and the IANA does not recognize the number at all. The DOS code page switching file `NECPINW.CPI` for NEC Pinwriters supported the Kamenický encoding under both, code page 867 and 895 as well.[8] This encoding is known as code page 3844 in Star printers.

## Character set[edit]

Each character is shown with its equivalent Unicode code point. Only the second half of the table (code points 128–255) is shown, the first half (code points 0–127) being the same as ASCII and code page 437. Differences from code page 437 are boxed.[2][1]

Code page 867 / 895
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
8_ 128 | Č 010C | ü 00FC | é 00E9 | ď 010F | ä 00E4 | Ď 010E | Ť 0164 | č 010D | ě 011B | Ě 011A | Ĺ 0139 | Í 00CD | ľ 013E | ĺ 013A | Ä 00C4 | Á 00C1
9_ 144 | É 00C9 | ž 017E | Ž 017D | ô 00F4 | ö 00F6 | Ó 00D3 | ů 016F | Ú 00DA | ý 00FD | Ö 00D6 | Ü 00DC | Š 0160 | Ľ 013D | Ý 00DD | Ř 0158 | ť 0165
A_ 160 | á 00E1 | í 00ED | ó 00F3 | ú 00FA | ň 0148 | Ň 0147 | Ů 016E | Ô 00D4 | š 0161 | ř 0159 | ŕ 0155 | Ŕ 0154 | ¼ 00BC | §[a] 00A7 | « 00AB | » 00BB
B_ 176 | ░ 2591 | ▒ 2592 | ▓ 2593 | │ 2502 | ┤ 2524 | ╡ 2561 | ╢ 2562 | ╖ 2556 | ╕ 2555 | ╣ 2563 | ║ 2551 | ╗ 2557 | ╝ 255D | ╜ 255C | ╛ 255B | ┐ 2510
C_ 192 | └ 2514 | ┴ 2534 | ┬ 252C | ├ 251C | ─ 2500 | ┼ 253C | ╞ 255E | ╟ 255F | ╚ 255A | ╔ 2554 | ╩ 2569 | ╦ 2566 | ╠ 2560 | ═ 2550 | ╬ 256C | ╧ 2567
D_ 208 | ╨ 2568 | ╤ 2564 | ╥ 2565 | ╙ 2559 | ╘ 2558 | ╒ 2552 | ╓ 2553 | ╫ 256B | ╪ 256A | ┘ 2518 | ┌ 250C | █ 2588 | ▄ 2584 | ▌ 258C | ▐ 2590 | ▀ 2580
E_ 224 | α 03B1 | ß 00DF | Γ 0393 | π 03C0 | Σ 03A3 | σ 03C3 | µ 00B5 | τ 03C4 | Φ 03A6 | Θ 0398 | Ω 03A9 | δ 03B4 | ∞ 221E | φ 03C6 | ε 03B5 | ∩ 2229
F_ 240 | ≡ 2261 | ± 00B1 | ≥ 2265 | ≤ 2264 | ⌠ 2320 | ⌡ 2321 | ÷ 00F7 | ≈ 2248 | ° 00B0 | ∙ 2219 | · 00B7 | √ 221A | ⁿ 207F | ² 00B2 | ■ 25A0 | NBSP 00A0

Letter Number Punctuation Symbol Other Undefined

1. ^ The Czech DOS word processor Text602 [cs] aka T602 assigned code point 173 to a section sign (`U+00A7`) in Kamenický encoding. While the original display[1] and printer fonts[2] defined code point 173 as section sign ('§', `U+00A7`), some tools also used an inverted exclamation mark ('¡', `U+00A1`) instead, which comes from CP437. This variant is not fully compliant with the definition of code page 867 / 895 and should therefore not be associated with these numbers.

## See also[edit]

- Mazovia encoding – similar code page for Polish
- CWI-2 encoding
- Hardware code page

## References[edit]

1. ^ a b c d e f g
   Petrlik, Lukas (1996-06-19). "The Czech and Slovak Character Encoding Mess Explained". cs-encodings-faq. 1.10. Archived from the original on 2016-06-21. Retrieved 2016-06-21.
2. ^ a b c d Pinwriter Familie - Pinwriter - Epromsockel - Zusätzliche Zeichensätze / Schriftarten (Printed reference manual for optional font and codepage EPROMs for NEC Pinwriters, including custom variants) (in German) (00 3/93 ed.), NEC Deutschland GmbH, 1993
3. ^ NEC Pinwriter. Ein Maßstab in der Profiklasse. (Printed 11-page color flyer about NEC Pinwriters P20/P30, P60/P70 and P90) (in German) (P-EAM-D-5/92 ed.), NEC Deutschland GmbH, 1992 (NB. According to this publication, these printers included optional support for code page 867 (CP867), as it were also supported in display fonts in MS-DOS 5.0 and DR DOS 6.0.)
4. ^ "Code Page (CPGID) 00867: Israel - Personal Computer", REGISTRY, Graphic Character Sets and Code Pages, IBM Corporation, 1998, retrieved 2014-06-02
5. ^ Fujitsu DL6400/DL6600 Dot Matrix Printer User's Manual (PDF). Fujitsu Limited. April 1994. C147-E015-01EN. Archived (PDF) from the original on 2016-06-14. Retrieved 2016-06-14.
6. ^ Kostis, Kosta; Michl, Vladimir. "MS-DOS Codepage 895 (Kamenicky CS)". 1.00. Archived from the original on 2017-02-19. Retrieved 2017-02-19.
7. ^ Smělý, Roman (2001-05-27). "Bratři Kameničtí: výsledné rozhodnutí jsme neučinili my, ale uživatelé" [Brothers Kameničtí: the final decision was not taken by us, but users]. Connect! [de] (in Czech) (Czech ed.). 2001 (5). Archived from the original on 2017-02-18. Retrieved 2017-02-18.
8. ^ a b c d Paul, Matthias R. (2001) [1996], "Specification and reference documentation for NECPINW", NECPINW.CPI - DOS code page switching driver for NEC Pinwriters (2.08 ed.), FILESPEC.TXT from NECPI208.ZIP, archived from the original on 2017-09-10, retrieved 2013-04-22
9. ^ Character Data Representation Architecture (CDRA) level 2 - Reference. IBM. 1993. SC09-1390-01.
10. ^ "Codepages". IBM. 2013.

Retrieved from "https://en.wikipedia.org/w/index.php?title=Kamenický_encoding&oldid=981914359"
Categories:

- DOS code pages

Hidden categories:

- CS1 German-language sources (de)
- CS1 Czech-language sources (cs)
- Articles containing Czech-language text